/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SDPMMOTION_H
#define SDPMMOTION_H

#include "sdpm.h"
#include "sdpmObject.h"
#include <vector>

namespace sdpm
{

/**
 * @brief Hold the parameters defning the motion of a body and compute the induced velocity
 * @authors Adrien Crovato
 */
class SDPM_API Motion : public sdpmObject
{
    sdpmDouble _aAmp;               ///< pitch amplitude
    sdpmDouble _hAmp;               ///< plunge amplitude
    sdpmDouble _xRef;               ///< x-coordinate of center of pitch
    sdpmDouble _zRef;               ///< z-coordinate of center of pitch
    sdpmDouble _mAmp;               ///< modal amplitude
    std::vector<sdpmDouble> _dzMod; ///< modal displacements along z
    std::vector<sdpmDouble> _rxMod; ///< modal rotations about x
    std::vector<sdpmDouble> _ryMod; ///< modal rotations about y

public:
    Motion(size_t n);
    ~Motion(){};

    sdpmDouble getPitchAmplitude() const { return _aAmp; }
    std::vector<sdpmDouble> const &getModeZ() const { return _dzMod; }
    void setRigid(double aAmp, double hAmp, double xRef, double zRef);
    void setFlexible(double mAmp, std::vector<std::vector<double>> const &xMod, std::vector<Node *> const &nodes);
    sdpmVector3d computeSteady(Element const &e, sdpmVector3d const &ui);
    sdpmVector3d computeHarmonic(Element const &e);
};

} // namespace sdpm

#endif // SDPMMOTION_H
