/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SDPMNODE_H
#define SDPMNODE_H

#include "sdpm.h"
#include "sdpmObject.h"

namespace sdpm
{

/**
 * @brief Node data structure
 * @authors Adrien Crovato
 */
class SDPM_API Node : public sdpmObject
{
    friend class Adjoint; // so that Adjoint can access the node coordinates

    size_t _id;          ///< node number
    sdpmVector3d _coord; ///< node coordinates

public:
    Node(size_t n, sdpmVector3d const &c) : sdpmObject(), _id(n), _coord(c) {}

    size_t getId() { return _id; }
    size_t const &getIdRef() { return _id; }
    sdpmVector3d getCoords() { return _coord; }

#ifndef SWIG
    virtual void write(std::ostream &out) const override;
#endif
};

} // namespace sdpm

#endif // SDPMNODE_H
